@@ -33,7 +33,7 @@ def register():
 
 class Submonitor(submonitor_base.SubmonitorBase):
     def setup(self, options):
-        self._log = logging.getLogger("%s.EngineHealth" % __name__)
+        self._log = logging.getLogger("%s.StorageDomain" % __name__)
         self._log.addFilter(log_filter.get_intermittent_filter())
 
         self.sd_uuid = options["sd_uuid"]
